@@ -1,16 +1,26 @@
 import codecs
 import datetime
 import json
-import pytz
-import requests
 import unittest
 
+import pytz
+import requests
 from requests.structures import CaseInsensitiveDict
-from . import __version__
-from .clients import BaseClient
+
+from . import CLIENT_VERSION
+from .base import BaseClient
 from .exceptions import TembaException, TembaSerializationException
-from .serialization import TembaObject, SimpleField, BooleanField, IntegerField, DatetimeField, ObjectField
-from .serialization import ObjectListField, ObjectDictField
+from .serialization import (
+    BooleanField,
+    DatetimeField,
+    IntegerField,
+    ListField,
+    ObjectDictField,
+    ObjectField,
+    ObjectListField,
+    SimpleField,
+    TembaObject,
+)
 from .utils import format_iso8601, parse_iso8601
 
 
@@ -52,7 +62,7 @@ class TembaTest(unittest.TestCase):
                 "Content-type": "application/json",
                 "Authorization": "Token 1234567890",
                 "Accept": u"application/json",
-                "User-Agent": "test/0.1 rapidpro-python/%s" % __version__,
+                "User-Agent": "test/0.1 rapidpro-python/%s" % CLIENT_VERSION,
             },
             verify=None,
             **kwargs
@@ -106,6 +116,12 @@ class TestType(TembaObject):
     meh = ObjectDictField(item_class=TestSubType)
 
 
+class TembaSerializationExceptionTest(TembaTest):
+    def test_str_works(self):
+        err = TembaSerializationException("boop")
+        self.assertEqual(str(err), "boop")
+
+
 class FieldsTest(TembaTest):
     def test_boolean(self):
         field = BooleanField()
@@ -131,6 +147,17 @@ class FieldsTest(TembaTest):
         self.assertRaises(TembaSerializationException, field.deserialize, "")
         self.assertRaises(TembaSerializationException, field.deserialize, [])
 
+    def test_list(self):
+        field = ListField()
+        self.assertEqual(field.serialize([]), [])
+        self.assertEqual(field.serialize(None), None)
+
+        self.assertEqual(field.deserialize([]), [])
+        self.assertEqual(field.deserialize(None), None)
+
+        self.assertRaises(TembaSerializationException, field.deserialize, 1.5)
+        self.assertRaises(TembaSerializationException, field.deserialize, "")
+
     def test_object_list(self):
         field = ObjectListField(item_class=TestSubType)
         self.assertEqual(
@@ -243,7 +270,7 @@ class BaseClientTest(TembaTest):
                 "Content-type": "application/json",
                 "Accept": "application/json",
                 "Authorization": "Token 1234567890",
-                "User-Agent": "test/0.1 rapidpro-python/%s" % __version__,
+                "User-Agent": "test/0.1 rapidpro-python/%s" % CLIENT_VERSION,
             },
         )
 
@@ -256,7 +283,7 @@ class BaseClientTest(TembaTest):
                 "Content-type": "application/json",
                 "Accept": "application/json",
                 "Authorization": "Token 1234567890",
-                "User-Agent": "rapidpro-python/%s" % __version__,
+                "User-Agent": "rapidpro-python/%s" % CLIENT_VERSION,
             },
         )
 
