@@ -360,7 +360,9 @@ class TembaClient(BaseCursorClient):
         """
         return Field.deserialize(self._post("fields", None, self._build_params(label=label, value_type=value_type)))
 
-    def create_flow_start(self, flow, urns=None, contacts=None, groups=None, restart_participants=None, params=None):
+    def create_flow_start(
+        self, flow, urns=None, contacts=None, groups=None, restart_participants=None, exclude_active=None, params=None
+    ):
         """
         Creates a new flow start
 
@@ -369,6 +371,7 @@ class TembaClient(BaseCursorClient):
         :param list[str] contacts: UUIDs of contacts to start
         :param list[str] groups: UUIDs of contact groups to start
         :param bool restart_participants: whether to restart participants already in this flow
+        :param bool exclude_active: whether to exclude contacts currently in other flows
         :param * params: a dictionary of parameters to pass to the flow
         :return: the new label
         """
@@ -378,6 +381,7 @@ class TembaClient(BaseCursorClient):
             contacts=contacts,
             groups=groups,
             restart_participants=restart_participants,
+            exclude_active=exclude_active,
             params=params,
         )
         return FlowStart.deserialize(self._post("flow_starts", None, payload))
